Package: rqdatatable
Type: Package
Title: 'rquery' for 'data.table'
Version: 1.3.3
Date: 2023-08-19
Authors@R: c(
    person("John", "Mount", email = "jmount@win-vector.com", role = c("aut", "cre")),
    person(family = "Win-Vector LLC", role = c("cph"))
    )
Maintainer: John Mount <jmount@win-vector.com>
Description: Implements the 'rquery' piped Codd-style query algebra using 'data.table'.  This allows
   for a high-speed in memory implementation of Codd-style data manipulation tools.
URL: https://github.com/WinVector/rqdatatable/,
        https://winvector.github.io/rqdatatable/
BugReports: https://github.com/WinVector/rqdatatable/issues
License: GPL-2 | GPL-3
Encoding: UTF-8
ByteCompile: true
VignetteBuilder: knitr
Depends: R (>= 3.4.0), wrapr (>= 2.0.9), rquery (>= 1.4.9)
Imports: data.table (>= 1.12.2)
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown, DBI, RSQLite, parallel, tinytest
NeedsCompilation: no
Packaged: 2023-08-20 05:23:02 UTC; johnmount
Author: John Mount [aut, cre],
  Win-Vector LLC [cph]
Repository: CRAN
Date/Publication: 2023-08-21 08:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 03:01:38 UTC; unix
