# Generated by roxygen2: do not edit by hand

S3method(ex_data_table_step,default)
S3method(ex_data_table_step,relop_drop_columns)
S3method(ex_data_table_step,relop_extend)
S3method(ex_data_table_step,relop_natural_join)
S3method(ex_data_table_step,relop_non_sql)
S3method(ex_data_table_step,relop_null_replace)
S3method(ex_data_table_step,relop_order_expr)
S3method(ex_data_table_step,relop_orderby)
S3method(ex_data_table_step,relop_project)
S3method(ex_data_table_step,relop_rename_columns)
S3method(ex_data_table_step,relop_select_columns)
S3method(ex_data_table_step,relop_select_rows)
S3method(ex_data_table_step,relop_set_indicator)
S3method(ex_data_table_step,relop_sql)
S3method(ex_data_table_step,relop_table_source)
S3method(ex_data_table_step,relop_theta_join)
S3method(ex_data_table_step,relop_unionall)
export(as.data.table)
export(ex_data_table)
export(ex_data_table_parallel)
export(ex_data_table_step)
export(layout_to_blocks_data_table)
export(layout_to_rowrecs_data_table)
export(make_dt_lookup_by_column)
export(rbindlist_data_table)
export(rq_df_funciton_node)
export(rq_df_grouped_funciton_node)
export(set_rqdatatable_as_executor)
importFrom(data.table,":=")
importFrom(data.table,as.data.table)
importFrom(data.table,is.data.table)
importFrom(parallel,clusterApplyLB)
importFrom(rquery,column_names)
importFrom(rquery,columns_used)
importFrom(rquery,local_td)
importFrom(rquery,non_sql_node)
importFrom(rquery,rquery_apply_to_data_frame)
importFrom(wrapr,"%:=%")
